/**
 * The main entrypoint when using Tsx as the runtime
 */
import { IRuntime, RunTimeType } from '../common/runtime.ts';
import TsxTerminalIO from './terminal_io.ts';
import TsxFileIO from './file_io.ts';

import process from 'node:process';

/**
 * The Tsx Runtime implementation
 */
const TsxRuntime: IRuntime = {
	name: RunTimeType.Tsx,
	file: TsxFileIO,
	term: TsxTerminalIO,
	onEvent: (eventName: string, handler) => process.on(eventName, handler),
	onExit: (cb: () => void): void => {
		process.on('beforeExit', cb);
		process.on('exit', cb);
		process.on('SIGINT', cb);
	},
	exit: (code?: number) => process.exit(code),
};

export default TsxRuntime;
